# pydantic-extra-types

A place for pydantic types that probably shouldn't exist in the main pydantic lib.

See [pydantic/pydantic#5012](https://github.com/pydantic/pydantic/issues/5012) for more info.

This is just a stub to reserve the name `pydantic-extra-types`.
